==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RiskPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.util.LinkedHashSet;
import java.util.Set;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RiskPolicyRuleCondition
 */
@JsonPropertyOrder({ RiskPolicyRuleCondition.JSON_PROPERTY_BEHAVIORS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RiskPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BEHAVIORS = "behaviors";
    private Set<String> behaviors = null;

    public RiskPolicyRuleCondition() {
    }

    public RiskPolicyRuleCondition behaviors(Set<String> behaviors) {

        this.behaviors = behaviors;
        return this;
    }

    public RiskPolicyRuleCondition addbehaviorsItem(String behaviorsItem) {
        if (this.behaviors == null) {
            this.behaviors = new LinkedHashSet<>();
        }
        this.behaviors.add(behaviorsItem);
        return this;
    }

    /**
     * Get behaviors
     *
     * @return behaviors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BEHAVIORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Set<String> getBehaviors() {
        return behaviors;
    }

    @JsonDeserialize(as = LinkedHashSet.class)
    @JsonProperty(JSON_PROPERTY_BEHAVIORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBehaviors(Set<String> behaviors) {
        this.behaviors = behaviors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RiskPolicyRuleCondition riskPolicyRuleCondition = (RiskPolicyRuleCondition) o;
        return Objects.equals(this.behaviors, riskPolicyRuleCondition.behaviors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(behaviors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RiskPolicyRuleCondition {\n");
        sb.append("    behaviors: ").append(toIndentedString(behaviors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/RiskPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.util.LinkedHashSet;
import java.util.Set;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RiskPolicyRuleCondition
 */
@JsonPropertyOrder({ RiskPolicyRuleCondition.JSON_PROPERTY_BEHAVIORS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RiskPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BEHAVIORS = "behaviors";
    private Set<String> behaviors = null;

    public RiskPolicyRuleCondition() {
    }

    public RiskPolicyRuleCondition behaviors(Set<String> behaviors) {

        this.behaviors = behaviors;
        return this;
    }

    public RiskPolicyRuleCondition addbehaviorsItem(String behaviorsItem) {
        if (this.behaviors == null) {
            this.behaviors = new LinkedHashSet<>();
        }
        this.behaviors.add(behaviorsItem);
        return this;
    }

    /**
     * Get behaviors
     *
     * @return behaviors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BEHAVIORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Set<String> getBehaviors() {
        return behaviors;
    }

    @JsonDeserialize(as = LinkedHashSet.class)
    @JsonProperty(JSON_PROPERTY_BEHAVIORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBehaviors(Set<String> behaviors) {
        this.behaviors = behaviors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RiskPolicyRuleCondition riskPolicyRuleCondition = (RiskPolicyRuleCondition) o;
        return Objects.equals(this.behaviors, riskPolicyRuleCondition.behaviors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(behaviors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RiskPolicyRuleCondition {\n");
        sb.append("    behaviors: ").append(toIndentedString(behaviors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
